==> scorched3d_38.1.orig.tar.gz: scorched3d-38.1/src/actions/TankDamage.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////


#if !defined(__INCLUDE_TankDamageh_INCLUDE__)
#define __INCLUDE_TankDamageh_INCLUDE__

#include <engine/ActionMeta.h>
#include <weapons/Weapon.h>

class TankDamage : public ActionMeta
{
public:
	TankDamage();
	TankDamage(Weapon *weapon, 
		unsigned int damagedPlayerId, unsigned int firedPlayerId,
		float damage, bool useShieldDamage, bool checkFall,
		unsigned int data);
	virtual ~TankDamage();

	virtual void init();
	virtual void simulate(float frameTime, bool &remove);
	virtual bool writeAction(NetBuffer &buffer);
	virtual bool readAction(NetBufferReader &reader);

	REGISTER_ACTION_HEADER(TankDamage);

protected:
	bool firstTime_;
	
	Weapon *weapon_;
	unsigned int damagedPlayerId_;
	unsigned int firedPlayerId_;
	float damage_;
	bool useShieldDamage_, checkFall_;
	unsigned int data_;
};


#endif

==> scorched3d_41.3dfsg.orig.tar.gz: scorched3d-41.3dfsg/src/actions/TankDamage.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////


#if !defined(__INCLUDE_TankDamageh_INCLUDE__)
#define __INCLUDE_TankDamageh_INCLUDE__

#include <engine/ActionReferenced.h>
#include <weapons/Weapon.h>

class TankDamage : public ActionReferenced
{
public:
	TankDamage(Weapon *weapon, 
		unsigned int damagedPlayerId, WeaponFireContext &weaponContext,
		fixed damage, bool useShieldDamage, bool checkFall,
		bool shieldOnlyDamage);
	virtual ~TankDamage();

	virtual void init();
	virtual void simulate(fixed frameTime, bool &remove);
	virtual const char *getActionDetails();

protected:
	bool firstTime_;
	Weapon *weapon_;
	WeaponFireContext weaponContext_;
	unsigned int damagedPlayerId_;
	fixed damage_;
	bool useShieldDamage_, checkFall_, shieldOnlyDamage_;

	void calculateDamage();
	void calculateDeath();
	void logDeath();
};


#endif
